# MusicalMusic
[![Downloads](https://pepy.tech/badge/musicalmusic)](https://pepy.tech/project/musicalmusic)[![Build Status](https://travis-ci.org/frankye8998/MusicalMusic.svg?branch=master)](https://travis-ci.org/frankye8998/MusicalMusic)

MusicalMusic is a Musescore wrapper for Python 3.
## Installing
To Install the full library, run the following command:
```
pip install MusicalMusic -U
```
## Authors
* **Frank Ye** - frankfrankfrankyeyeye@gmail.com
## License
This project is licensed under the GPL 3.0 License - see the [LICENSE.txt](LICENSE.txt) file for details.
